@@ -61,26 +61,18 @@ async def async_main():
         case CliAction.chunks:
             from vectorcode.subcommands import chunks
 
-            return_val = await chunks(final_configs)
-        case CliAction.hooks:
-            logger.warning(
-                "`vectorcode hooks` has been deprecated and will be removed in 0.7.0."
-            )
-            logger.warning("Please use `vectorcode init --hooks`.")
-            from vectorcode.subcommands import hooks
-
-            return await hooks(cli_args)
+            return await chunks(final_configs)
 
     from vectorcode.common import start_server, try_server
 
     server_process = None
-    if not await try_server(final_configs.host, final_configs.port):
+    if not await try_server(final_configs.db_url):
         server_process = await start_server(final_configs)
 
-    if final_configs.pipe:
+    if final_configs.pipe:  # pragma: nocover
         # NOTE: NNCF (intel GPU acceleration for sentence transformer) keeps showing logs.
         # This disables logs below ERROR so that it doesn't hurt the `pipe` output.
-        logging.disable(logging.ERROR)
+        logging.disable(logging.ERROR - 1)
 
     return_val = 0
     try:
@@ -109,9 +101,8 @@ async def async_main():
                 from vectorcode.subcommands import clean
 
                 return_val = await clean(final_configs)
-    except Exception as e:
+    except Exception:
         return_val = 1
-        traceback.print_exception(e, file=sys.stderr)
         logger.error(traceback.format_exc())
     finally:
         if server_process is not None:
