@@ -1,4 +1,5 @@
 from vectorcode.subcommands.check import check
+from vectorcode.subcommands.chunks import chunks
 from vectorcode.subcommands.clean import clean
 from vectorcode.subcommands.drop import drop
 from vectorcode.subcommands.init import init
@@ -9,13 +10,14 @@ from vectorcode.subcommands.update import update
 from vectorcode.subcommands.vectorise import vectorise
 
 __all__ = [
+    "check",
+    "chunks",
+    "clean",
     "drop",
     "init",
-    "query",
     "ls",
-    "vectorise",
-    "check",
-    "update",
-    "clean",
     "prompts",
+    "query",
+    "update",
+    "vectorise",
 ]
