@@ -41,13 +41,11 @@ def add_reranker(cls):
     if issubclass(cls, RerankerBase):
         if __supported_rerankers.get(cls.__name__):
             error_message = f"{cls.__name__} has been registered."
-            logger.error(error_message)
             raise AttributeError(error_message)
         __supported_rerankers[cls.__name__] = cls
         return cls
     else:
         error_message = f'{cls} should be a subclass of "RerankerBase"'
-        logger.error(error_message)
         raise TypeError(error_message)
 
 
@@ -66,16 +64,7 @@ def get_reranker(configs: Config) -> RerankerBase:
         ):
             return __supported_rerankers[configs.reranker].create(configs)
 
-    # TODO: replace the following with an Exception before the release of 0.6.0.
-    logger.warning(
-        f""""reranker" option should be set to one of the following: {list(i.__name__ for i in get_available_rerankers())}.
-To choose a CrossEncoderReranker model, you can set the "model_name_or_path" key in the "reranker_params" option to the name/path of the model.
-To use NaiveReranker, set the "reranker" option to "NaiveReranker".
-The old configuration syntax will be DEPRECATED in v0.6.0
-                """
-    )
     if not configs.reranker:
         return NaiveReranker(configs)
     else:
-        logger.error(f"{configs.reranker} is not a valid reranker type!")
         raise RerankerInitialisationError()
